==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Watchlist.java <==
package com.example.model;

/**
 * Model for Watchlist
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "Watchlist", description = "Model for Watchlist")
@javax.xml.bind.annotation.XmlRootElement(name = "Watchlist")
public class Watchlist implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.util.List<java.lang.String> erroR = new java.util.ArrayList<java.lang.String>();
	private java.util.List<java.lang.String> foundonlisT = null;
	private java.util.List<java.lang.String> notfoundonlisT = null;
	
	/**
	 */
	public Watchlist erroR(java.util.List<java.lang.String> erroR) {
		setErroR(erroR);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("ERROR")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public java.util.List<java.lang.String> getErroR() {
		return this.erroR;
	}
	public void setErroR(java.util.List<java.lang.String> erroR) {
		this.erroR = erroR;
	}
	public Watchlist addErroR(java.lang.String erroR) {
		if (this.erroR == null) {
			this.erroR = new java.util.ArrayList<java.lang.String>();
		}
		this.erroR.add(erroR);
		return this;
	}
	
	/**
	 */
	public Watchlist foundonlisT(java.util.List<java.lang.String> foundonlisT) {
		setFoundonlisT(foundonlisT);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("FOUND_ON_LIST")
	@javax.validation.Valid
	public java.util.List<java.lang.String> getFoundonlisT() {
		return this.foundonlisT;
	}
	public void setFoundonlisT(java.util.List<java.lang.String> foundonlisT) {
		this.foundonlisT = foundonlisT;
	}
	public Watchlist addFoundonlisT(java.lang.String foundonlisT) {
		if (this.foundonlisT == null) {
			this.foundonlisT = new java.util.ArrayList<java.lang.String>();
		}
		this.foundonlisT.add(foundonlisT);
		return this;
	}
	
	/**
	 */
	public Watchlist notfoundonlisT(java.util.List<java.lang.String> notfoundonlisT) {
		setNotfoundonlisT(notfoundonlisT);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("NOT_FOUND_ON_LIST")
	@javax.validation.Valid
	public java.util.List<java.lang.String> getNotfoundonlisT() {
		return this.notfoundonlisT;
	}
	public void setNotfoundonlisT(java.util.List<java.lang.String> notfoundonlisT) {
		this.notfoundonlisT = notfoundonlisT;
	}
	public Watchlist addNotfoundonlisT(java.lang.String notfoundonlisT) {
		if (this.notfoundonlisT == null) {
			this.notfoundonlisT = new java.util.ArrayList<java.lang.String>();
		}
		this.notfoundonlisT.add(notfoundonlisT);
		return this;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Watchlist watchlist = (Watchlist) o;
		return java.util.Objects.equals(this.erroR, watchlist.erroR)
				&& java.util.Objects.equals(this.foundonlisT, watchlist.foundonlisT)
				&& java.util.Objects.equals(this.notfoundonlisT, watchlist.notfoundonlisT);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.erroR, this.foundonlisT, this.notfoundonlisT);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Watchlist {\n");
		
		sb.append("    erroR: ").append(toIndentedString(this.erroR)).append("\n");
		sb.append("    foundonlisT: ").append(toIndentedString(this.foundonlisT)).append("\n");
		sb.append("    notfoundonlisT: ").append(toIndentedString(this.notfoundonlisT)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Watchlist.java <==
package com.example.model;

/**
 * Model for Watchlist
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "Watchlist", description = "Model for Watchlist")
@javax.xml.bind.annotation.XmlRootElement(name = "Watchlist")
public class Watchlist implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.util.List<java.lang.String> erroR = new java.util.ArrayList<java.lang.String>();
	private java.util.List<java.lang.String> foundonlisT = null;
	private java.util.List<java.lang.String> notfoundonlisT = null;
	
	/**
	 */
	public Watchlist erroR(java.util.List<java.lang.String> erroR) {
		setErroR(erroR);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "ERROR")
	@com.fasterxml.jackson.annotation.JsonProperty("ERROR")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public java.util.List<java.lang.String> getErroR() {
		return this.erroR;
	}
	public void setErroR(java.util.List<java.lang.String> erroR) {
		this.erroR = erroR;
	}
	public Watchlist addErroR(java.lang.String erroR) {
		if (this.erroR == null) {
			this.erroR = new java.util.ArrayList<java.lang.String>();
		}
		this.erroR.add(erroR);
		return this;
	}
	
	/**
	 */
	public Watchlist foundonlisT(java.util.List<java.lang.String> foundonlisT) {
		setFoundonlisT(foundonlisT);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "FOUND_ON_LIST")
	@com.fasterxml.jackson.annotation.JsonProperty("FOUND_ON_LIST")
	@javax.validation.Valid
	public java.util.List<java.lang.String> getFoundonlisT() {
		return this.foundonlisT;
	}
	public void setFoundonlisT(java.util.List<java.lang.String> foundonlisT) {
		this.foundonlisT = foundonlisT;
	}
	public Watchlist addFoundonlisT(java.lang.String foundonlisT) {
		if (this.foundonlisT == null) {
			this.foundonlisT = new java.util.ArrayList<java.lang.String>();
		}
		this.foundonlisT.add(foundonlisT);
		return this;
	}
	
	/**
	 */
	public Watchlist notfoundonlisT(java.util.List<java.lang.String> notfoundonlisT) {
		setNotfoundonlisT(notfoundonlisT);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "NOT_FOUND_ON_LIST")
	@com.fasterxml.jackson.annotation.JsonProperty("NOT_FOUND_ON_LIST")
	@javax.validation.Valid
	public java.util.List<java.lang.String> getNotfoundonlisT() {
		return this.notfoundonlisT;
	}
	public void setNotfoundonlisT(java.util.List<java.lang.String> notfoundonlisT) {
		this.notfoundonlisT = notfoundonlisT;
	}
	public Watchlist addNotfoundonlisT(java.lang.String notfoundonlisT) {
		if (this.notfoundonlisT == null) {
			this.notfoundonlisT = new java.util.ArrayList<java.lang.String>();
		}
		this.notfoundonlisT.add(notfoundonlisT);
		return this;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Watchlist watchlist = (Watchlist) o;
		return java.util.Objects.equals(this.erroR, watchlist.erroR)
				&& java.util.Objects.equals(this.foundonlisT, watchlist.foundonlisT)
				&& java.util.Objects.equals(this.notfoundonlisT, watchlist.notfoundonlisT);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.erroR, this.foundonlisT, this.notfoundonlisT);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Watchlist {\n");
		
		sb.append("    erroR: ").append(toIndentedString(this.erroR)).append("\n");
		sb.append("    foundonlisT: ").append(toIndentedString(this.foundonlisT)).append("\n");
		sb.append("    notfoundonlisT: ").append(toIndentedString(this.notfoundonlisT)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
